//=============================================================================
// TCOCommandlet.
// Description: --
// 
// Date: 2021
// ©copyright Francesco Biscazzo. All rights reserved.
//=============================================================================
class TCOCommandlet extends Commandlet;

function logHelp() {
	log(" ");
	
	log("[Commands]");
	parseCommand("HELP HELP");
	parseCommand("LIST_DEFAULTS HELP");
	parseCommand("RESET_TO_DEFAULT HELP");
	
	log(" ");
}

static function logDefaults() {
	local class<Object> currClass;

	log(" ");	
	log("[Configurable properties BEGIN]");
	log(" ");	
	
	currClass = class'TCOMutator';
	log("["$currClass$"]");
	class<TCOMutator>(currClass).static.logDefaults();
			
	log(" ");	
	log("[Configurable properties END]");
	log(" ");
}

function parseCommand(String fullCmd) {
	local String command, param1;
	local bool bCommandRecognized, bParamRecognized;
	local String processedParam;
	local int processedParamNum;
	local String logStr;
	local bool bHelp;
	
	class'TCOMutator'.static.setDefaultProperties();
	
	param1 = class'TCOUtils'.static.findParameter(fullCmd, 1);
	bHelp = param1 ~= "HELP";
	
	command = caps(class'TCOUtils'.static.findParameter(fullCmd, 0));
	bCommandRecognized = true;
	bParamRecognized = true;
	switch command {
		case "?":
		case "HELP":
		case "CMD":			
		case "CMDS":
			if (!bHelp)
				logHelp();
			else
				log(command$" - Displays this document.");
			
			break;
			
		case "LIST_DEFAULTS":
			if (!bHelp)
				logDefaults();
			else
				log(command$" - Lists the configurable properties which have a default.");
			
			break;
			
		case "RESET_TO_DEFAULT":
			if (!bHelp) {
				class'TCOMutator'.static.staticSaveConfig();
				log(" ");
				log("The configurable properties values have been reset to default.");
				log(" ");
			} else
				log(command$" - Sets the configurable properties to its default values.");
			
			break;
		
		default:
			bCommandRecognized = false;
			bParamRecognized = false;
	}
	
	if (!bCommandRecognized || !bParamRecognized) {
		if (!bCommandRecognized)
			logStr = class'TCOMutator'.default.unrecogCmdStr;
		else if (!bParamRecognized)
			logStr = class'TCOMutator'.default.unrecogParamStr;
		// Some strings start with the same sequence of characters so they need to be checked in a specific order.
		logStr = class'TCOUtils'.static.replaceStr(logStr, "%cmd", command);
		logStr = class'TCOUtils'.static.replaceStr(logStr, "%param_num", processedParamNum);
		logStr = class'TCOUtils'.static.replaceStr(logStr, "%param", processedParam);
		//warn(logStr);
		log(logStr);
		
		logHelp();
	}
}

event int main(String parms) {
	//super.main(parms);

	parseCommand(parms);
	
	return 0;
}

defaultproperties {
	helpUsage="<commandlet> <command> [parameter_1] [parameter_n] ...    Send the command help to show a more detailed help document."
	showBanner=False
}
